@@ -24,11 +24,12 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#undef GTK_DISABLE_DEPRECATED
-
-#include <config.h>
+#include "config.h"
 #include <string.h> /* memset */
 
+#undef GTK_DISABLE_DEPRECATED
+#define __GTK_LIST_C__
+
 #include "gtklist.h"
 #include "gtklistitem.h"
 #include "gtkmain.h"
@@ -36,6 +37,7 @@
 #include "gtklabel.h"
 #include "gtkmarshalers.h"
 #include "gtkintl.h"
+
 #include "gtkalias.h"
 
 enum {
@@ -254,7 +256,7 @@ gtk_list_class_init (GtkListClass *class)
 		    _gtk_marshal_VOID__VOID,
 		    GTK_TYPE_NONE, 0);
   list_signals[SELECT_CHILD] =
-    gtk_signal_new (I_("select_child"),
+    gtk_signal_new (I_("select-child"),
 		    GTK_RUN_FIRST,
 		    GTK_CLASS_TYPE (object_class),
 		    GTK_SIGNAL_OFFSET (GtkListClass, select_child),
@@ -262,7 +264,7 @@ gtk_list_class_init (GtkListClass *class)
 		    GTK_TYPE_NONE, 1,
 		    GTK_TYPE_WIDGET);
   list_signals[UNSELECT_CHILD] =
-    gtk_signal_new (I_("unselect_child"),
+    gtk_signal_new (I_("unselect-child"),
 		    GTK_RUN_FIRST,
 		    GTK_CLASS_TYPE (object_class),
 		    GTK_SIGNAL_OFFSET (GtkListClass, unselect_child),
@@ -870,11 +872,11 @@ gtk_list_set_focus_child (GtkContainer *container,
       if (container->focus_child)
 	{
 	  list->last_focus_child = container->focus_child;
-	  gtk_widget_unref (container->focus_child);
+	  g_object_unref (container->focus_child);
 	}
       container->focus_child = child;
       if (container->focus_child)
-        gtk_widget_ref (container->focus_child);
+        g_object_ref (container->focus_child);
     }
 
   /* check for v adjustment */
@@ -982,47 +984,47 @@ gtk_list_insert_items (GtkList *list,
       tmp_list = tmp_list->next;
 
       gtk_widget_set_parent (widget, GTK_WIDGET (list));
-      gtk_signal_connect (GTK_OBJECT (widget), "drag_begin",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_drag_begin),
+      gtk_signal_connect (GTK_OBJECT (widget), "drag-begin",
+			  G_CALLBACK (gtk_list_signal_drag_begin),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "toggle_focus_row",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_toggle_focus_row),
+      gtk_signal_connect (GTK_OBJECT (widget), "toggle-focus-row",
+			  G_CALLBACK (gtk_list_signal_toggle_focus_row),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "select_all",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_select_all),
+      gtk_signal_connect (GTK_OBJECT (widget), "select-all",
+			  G_CALLBACK (gtk_list_signal_select_all),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "unselect_all",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_unselect_all),
+      gtk_signal_connect (GTK_OBJECT (widget), "unselect-all",
+			  G_CALLBACK (gtk_list_signal_unselect_all),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "undo_selection",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_undo_selection),
+      gtk_signal_connect (GTK_OBJECT (widget), "undo-selection",
+			  G_CALLBACK (gtk_list_signal_undo_selection),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "start_selection",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_start_selection),
+      gtk_signal_connect (GTK_OBJECT (widget), "start-selection",
+			  G_CALLBACK (gtk_list_signal_start_selection),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "end_selection",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_end_selection),
+      gtk_signal_connect (GTK_OBJECT (widget), "end-selection",
+			  G_CALLBACK (gtk_list_signal_end_selection),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "extend_selection",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_extend_selection),
+      gtk_signal_connect (GTK_OBJECT (widget), "extend-selection",
+			  G_CALLBACK (gtk_list_signal_extend_selection),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "scroll_horizontal",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_scroll_horizontal),
+      gtk_signal_connect (GTK_OBJECT (widget), "scroll-horizontal",
+			  G_CALLBACK (gtk_list_signal_scroll_horizontal),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "scroll_vertical",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_scroll_vertical),
+      gtk_signal_connect (GTK_OBJECT (widget), "scroll-vertical",
+			  G_CALLBACK (gtk_list_signal_scroll_vertical),
 			  list);
-      gtk_signal_connect (GTK_OBJECT (widget), "toggle_add_mode",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_toggle_add_mode),
+      gtk_signal_connect (GTK_OBJECT (widget), "toggle-add-mode",
+			  G_CALLBACK (gtk_list_signal_toggle_add_mode),
 			  list);
       gtk_signal_connect (GTK_OBJECT (widget), "select",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_item_select),
+			  G_CALLBACK (gtk_list_signal_item_select),
 			  list);
       gtk_signal_connect (GTK_OBJECT (widget), "deselect",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_item_deselect),
+			  G_CALLBACK (gtk_list_signal_item_deselect),
 			  list);
       gtk_signal_connect (GTK_OBJECT (widget), "toggle",
-			  GTK_SIGNAL_FUNC (gtk_list_signal_item_toggle),
+			  G_CALLBACK (gtk_list_signal_item_toggle),
 			  list);
     }
 
@@ -1169,7 +1171,7 @@ gtk_list_clear_items (GtkList *list,
       widget = tmp_list->data;
       tmp_list = tmp_list->next;
 
-      gtk_widget_ref (widget);
+      g_object_ref (widget);
 
       if (widget->state == GTK_STATE_SELECTED)
 	gtk_list_unselect_child (list, widget);
@@ -1182,7 +1184,7 @@ gtk_list_clear_items (GtkList *list,
       if (widget == list->last_focus_child)
 	list->last_focus_child = NULL;
 
-      gtk_widget_unref (widget);
+      g_object_unref (widget);
     }
 
   g_list_free (start_list);
@@ -1290,9 +1292,9 @@ gtk_list_remove_items_internal (GtkList	 *list,
       widget = tmp_list->data;
       tmp_list = tmp_list->next;
 
-      gtk_widget_ref (widget);
+      g_object_ref (widget);
       if (no_unref)
-	gtk_widget_ref (widget);
+	g_object_ref (widget);
 
       if (widget == new_focus_child) 
 	{
@@ -1318,7 +1320,7 @@ gtk_list_remove_items_internal (GtkList	 *list,
       if (widget == list->last_focus_child)
 	list->last_focus_child = NULL;
 
-      gtk_widget_unref (widget);
+      g_object_unref (widget);
     }
   
   if (new_focus_child && new_focus_child != old_focus_child)
@@ -2475,7 +2477,7 @@ gtk_list_signal_item_select (GtkListItem *list_item,
       if (!sel_list)
 	{
 	  list->selection = g_list_prepend (list->selection, list_item);
-	  gtk_widget_ref (GTK_WIDGET (list_item));
+	  g_object_ref (list_item);
 	}
       gtk_signal_emit (GTK_OBJECT (list), list_signals[SELECTION_CHANGED]);
       break;
@@ -2503,7 +2505,7 @@ gtk_list_signal_item_deselect (GtkListItem *list_item,
     {
       list->selection = g_list_remove_link (list->selection, node);
       g_list_free_1 (node);
-      gtk_widget_unref (GTK_WIDGET (list_item));
+      g_object_unref (list_item);
       gtk_signal_emit (GTK_OBJECT (list), list_signals[SELECTION_CHANGED]);
     }
 }
@@ -2576,5 +2578,4 @@ gtk_list_drag_begin (GtkWidget      *widget,
     }
 }
 
-#define __GTK_LIST_C__
 #include "gtkaliasdef.c"
