@@ -25,7 +25,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 
 #include "gtkmessagedialog.h"
@@ -418,7 +418,7 @@ gtk_message_dialog_set_property (GObject      *object,
 				g_value_get_boolean (value));
       break;
     case PROP_IMAGE:
-      gtk_message_dialog_set_image (dialog, (GtkWidget *)g_value_get_object (value));
+      gtk_message_dialog_set_image (dialog, g_value_get_object (value));
       break;
 
     default:
@@ -628,6 +628,13 @@ gtk_message_dialog_set_image (GtkMessageDialog *dialog,
   GtkWidget *parent;
 
   g_return_if_fail (GTK_IS_MESSAGE_DIALOG (dialog));
+  g_return_if_fail (image == NULL || GTK_IS_WIDGET (image));
+
+  if (image == NULL)
+    {
+      image = gtk_image_new_from_stock (NULL, GTK_ICON_SIZE_DIALOG);
+      gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+    }
 
   priv = GTK_MESSAGE_DIALOG_GET_PRIVATE (dialog);
 
@@ -643,6 +650,24 @@ gtk_message_dialog_set_image (GtkMessageDialog *dialog,
   g_object_notify (G_OBJECT (dialog), "image");
 }
 
+/**
+ * gtk_message_dialog_get_image:
+ * @dialog: a #GtkMessageDialog
+ *
+ * Gets the dialog's image.
+ *
+ * Return value: the dialog's image
+ *
+ * Since: 2.14
+ **/
+GtkWidget *
+gtk_message_dialog_get_image (GtkMessageDialog *dialog)
+{
+  g_return_val_if_fail (GTK_IS_MESSAGE_DIALOG (dialog), NULL);
+
+  return dialog->image;
+}
+
 /**
  * gtk_message_dialog_set_markup:
  * @message_dialog: a #GtkMessageDialog
@@ -874,8 +899,7 @@ gtk_message_dialog_style_set (GtkWidget *widget,
 
   setup_primary_label_font (dialog);
 
-  if (GTK_WIDGET_CLASS (gtk_message_dialog_parent_class)->style_set)
-    (GTK_WIDGET_CLASS (gtk_message_dialog_parent_class)->style_set) (widget, prev_style);
+  GTK_WIDGET_CLASS (gtk_message_dialog_parent_class)->style_set (widget, prev_style);
 }
 
 #define __GTK_MESSAGE_DIALOG_C__
